#!/bin/bash

P=iconv-vc14
V=1.15
B=1


set -e

if ! [ -x ar-lib ]; then
	wget -O ar-lib "http://git.savannah.gnu.org/gitweb/?p=automake.git;a=blob_plain;f=lib/ar-lib;hb=HEAD"
	chmod a+x ar-lib
fi

if ! [ -x compile ]; then
	wget -O compile "http://git.savannah.gnu.org/gitweb/?p=automake.git;a=blob_plain;f=lib/compile;hb=HEAD"
	chmod a+x compile
fi

D=$PWD

#
# run batch file and source environment changes
#
fetchenv() {
	local IFS
	IFS=
	batch=$1	
	shift
	cmd /c set >$TEMP/srcenv
	cmd /c call `cygpath -w $batch` "$@" \>nul 2\>nul \& set >$TEMP/dstenv
	diff -u $TEMP/srcenv $TEMP/dstenv | sed -f $D/envdiff.sed >$TEMP/diffenv
	. $TEMP/diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $TEMP/srcenv $TEMP/dstenv $TEMP/diffenv
}

export ARCH=$1

case "$ARCH" in
x86)
	export OSGEO4W_ROOT="C:\\OSGeo4W"
	VCARCH=x86
	CONFHOST=i686-w64-mingw32
	;;

x86_64)
	export OSGEO4W_ROOT="C:\\OSGeo4W64"
	VCARCH=x64
	CONFHOST=x86_64-w64-mingw32
	;;

*)
	echo "Unsupported arch $ARCH" >&2
	exit 1
	;;
esac


fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/VC/vcvarsall.bat $VCARCH
export PATH=/cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/Common7/IDE:$D:$PATH

cd ..

./configure \
	--host=$CONFHOST \
	--prefix=$D/install-$ARCH/libs/vc14 \
	CC="$D/compile cl -nologo" \
	CFLAGS="-MD" \
	CXX="$D/compile cl -nologo" \
	CXXFLAGS="-MD" \
	CPPFLAGS="-D_WIN32_WINNT=_WIN32_WINNT_WIN8" \
       	LD="link" \
	NM="dumpbin -symbols" \
	STRIP=":" \
	AR="$D/ar-lib lib" \
	RANLIB=":"
make clean
# make check
make install

mkdir -p osgeo4w/install-$ARCH/bin
mv osgeo4w/install-$ARCH/libs/vc14/bin/*.dll osgeo4w/install-$ARCH/bin

R=../../$ARCH/release/$P

mkdir -p $R/$P-devel

tar -C $D/install-$ARCH --remove-files -cjf $R/$P-$V-$B.tar.bz2 bin/charset-1.dll bin/iconv-2.dll
cp COPYING $R/$P-$V-$B.txt
cp osgeo4w/libs.hint $R/setup.hint

tar -C $D/install-$ARCH --remove-files -cjf $R/$P-devel/$P-devel-$V-$B.tar.bz2 libs
cp COPYING $R/$P-devel/$P-devel-$V-$B.txt
cp osgeo4w/devel.hint $R/$P-devel/setup.hint

tar -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh osgeo4w/libs.hint osgeo4w/devel.hint osgeo4w/envdiff.sed
